#!/bin/ksh

pauses="TRUE"
# pauses="FALSE"

# SET_VMIXING_001.ksh

# ***************************
# REPLACEABLE PARAMETERS
# ***************************

# STRUCTURE OF RUN, SET BAT FILES

#  parameter #1: latitude
#  parameter #2: longitude
#  parameter #3: start height
#  parameter #4: directory for met files
#  parameter #5: name of met file
#  parameter #6: run name
#  parameter #7: stability method (KBLS)
#  parameter #8: PBL mixing scheme (KBLT)
#  parameter #9: Optional ouptut variables
#  parameter #10: start yr
#  parameter #11: start mo
#  parameter #12: start da
#  parameter #13: start hr
#  parameter #14: number of hours to run
#  parameter #15: KMIXD
#  parameter #16: KMIX0
#  parameter #17: RESULTS_DIR

echo ' '
echo '*********************************'
echo 'inside SET_VMIXING_001.ksh'
echo '**********************************'
echo ' '

lat=${1}          ; echo '           lat = '${lat}
long=${2}         ; echo '          long = '${long}
height=${3}       ; echo '        height = '${height}
met_dir=${4}      ; echo '       met_dir = '${met_dir}
met_file=${5}     ; echo '      met_file = '${met_file}
run_name=${6}     ; echo '      run name = '${run_name}
KBLS=${7}         ; echo '          KBLS = '${KBLS}
KBLT=${8}         ; echo '          KBLT = '${KBLT}
extra_var=${9}    ; echo '     extra_var = '${extra_var}
start_year=${10}  ; echo '    start year = '${start_year}
start_month=${11} ; echo '   start month = '${start_month}
start_day=${12}   ; echo '     start day = '${start_day}
start_hour=${13}  ; echo '    start hour = '${start_hour}
duration=${14}    ; echo 'duration (hrs) = '${duration}
KMIXD=${15}       ; echo '         KMIXD = '${KMIXD}
KMIX0=${16}       ; echo '         KMIX0 = '${KMIX0}
RESULTS_DIR=${17} ; echo '   RESULTS_DIR = '${RESULTS_DIR}

if [ ${pauses} == 'TRUE' ] ; then ; echo "Press ENTER to continue...\c" ; read junk ; echo "continuing..." ; fi

# *************************************************************
#   establish RESULTS directory
# *************************************************************

# if results directory does not exist, create it:
if [ -d ${RESULTS_DIR} ] ; then
echo results directory exists ${RESULTS_DIR}
else ; mkdir ${RESULTS_DIR} ; fi

# *************************************************************
#   WHAT A SIMPLE CONCENTRATION CONTROL FILE LOOKS LIKE
# *************************************************************

#  00 00 00 00
#  1
#  40.0 -90.0 10.0
#  -48
#  0
#  10000.0
#  1
#  ../metdata/
#  oct1618.BIN
#  ./
#  tdump

# *********************************************************************
#   first create CONTROL file
# *********************************************************************

# *********************************************************************
# 1. UTC Starting Time for the Simulation (year, month, day, hour)

#        Default: 00 00 00 00 00
#        Enter the two digit values for the UTC time that the calculation is to start.
#        Use 0's to start at the beginning (or end) of the file according to the
#        direction of the calculation. All zero values in this field will force the
#        calculation to use the time of the first (or last) record of the meteorological
#        data file. In the special case where year and month are zero, day, hour and minute
#        are treated as relative to the start or end of the file. For example, the first
#        record of the meteorological data file usually starts at 0000 UTC. An entry of
#        "00 00 01 12 00" would start the calculation 36 hours from the start of the data file.

#        NOTE that as this is the first time writing to the file, there is a single ">"
#        for subsequent writes, the ">>" symbol is used

typeset -Z2 YY=${start_year}
typeset -Z2 MM=${start_month}
typeset -Z2 DD=${start_day}
typeset -Z2 HH=${start_hour}

echo ${start_year} ${start_month} ${start_day} ${start_hour} >control.txt

# **********************************************************************
# 2. Number of Starting Locations
#              Default: 1

echo 1 >>control.txt

# **********************************************************************

# 3. Starting Location [lat,long, height (meters above ground)]
#       west longitudes are negative; south latitudes are negative

echo ${lat} ${long} ${height} >> control.txt

# **********************************************************************
# 4. Total Run Time for Simulation (hours)

#        Default: 48

#     Specifies the duration of the calculation in hours.
#     Backward calculations are entered as negative hours.
#     A backward trajectory starts from the trajectory termination
#     point and proceeds upwind.
#     Meteorological data are processed in reverse-time order.

echo ${duration} >>control.txt

# **********************************************************************

# 5. Vertical motion option

#        (0:data 1:isob 2:isen 3:dens 4:sigma 5:diverg 6:eta)
#        (7:     8:      9: upward, burst, downward; 10: downward only)

#        Default: 0

#        Indicates the vertical motion calculation method.
#        The default "data" selection will use the meteorological model's
#        vertical velocity fields; other options include isobaric,
#        isentropic, constant density, constant internal sigma coordinate,
#        computed from the velocity divergence, and a special transformation
#        to correct the vertical velocities when mapped from quasi-horizontal ETA
#        surfaces to HYSPLIT's internal terrain following sigma coordinate.

echo 0 >>control.txt

# **********************************************************************

# 6. Top of model domain (internal coordinates m-agl)

#        Default: 10000.0

#     Sets the vertical limit of the internal meteorological grid.
#        If calculations are not required above a certain level, fewer meteorological
#        data are processed thus speeding up the computation. Trajectories will
#        terminate when they reach this level. A secondary use of this parameter is
#        to set the model's internal scaling height - the height at which the
#        internal sigma surfaces go flat relative to terrain. The default internal
#        scaling height is set to 25 km but it is set to the top of the model
#        domain if the entry exceeds 25 km. Further, when meteorological data are
#        provided on terrain sigma surfaces it is assumed that the input data
#        were scaled to a height of 20 km (RAMS) or 34.8 km (COAMPS). If a different
#        height is required to decode the input data, it should be entered on
#        this line as the negative of the height. HYSPLIT's internal scaling height
#        remains at 25 km unless the absolute value of the domain top exceeds 25 km.

echo 10000.0 >>control.txt
# echo 25000.0 >>control.txt

# **********************************************************************

# 7. Number of Input Data Grids

#        Default: 1

#        Number of simultaneous input meteorological files. The following two entries
#        (directory and name) will be repeated this number of times. A simulation
#        will terminate when the computation is off all of the grids in either
#        space or time. Trajectory calculations will check the grid each time
#        step and use the finest resolution input data available at that location
#        at that time. When multiple meteorological grids have different resolution,
#        there is an additional restriction that there should be some overlap between
#        the grids in time, otherwise it is not possible to transfer a trajectory
#        position from one grid to another.

echo 1 >> control.txt

echo ${met_dir} >> control.txt

echo ${met_file} >> control.txt

echo 'have written met file directory and met file names to control file'

if [ ${pauses} == 'TRUE' ] ; then ; echo "Press ENTER to continue...\c" ; read junk ; echo "continuing..." ; fi

if [ -a CONTROL ] ; then ; rm CONTROL ; fi

mv control.txt CONTROL

# *************************************
#  DONE establishing CONTROL file
# *************************************

# **************************************************************
echo 'have written control file'
if [ ${pauses} == 'TRUE' ] ; then ; echo "Press ENTER to continue...\c" ; read junk ; echo "continuing..." ; fi
# **************************************************************

# *************************************
#  now establish SETUP.CFG file
# *************************************

if [ -a setup.txt ] ; then ; rm setup.txt ; fi

# first line of SETUP.CFG file contains Fortran "Namelist" group name
echo  "&SETUP" > setup.txt

#  KMIXD=0 mixed layer obtained from 0:input 1:temperature 2:TKE
echo "KMIXD="${KMIXD}","  >> setup.txt

#  KMIX0=250 minimum mixing depth
echo "KMIX0="${KMIX0}","  >> setup.txt

#   ---------------------------------------------------------------------------------
echo  "/"   >>setup.txt
#   ---------------------------------------------------------------------------------

if [ -a SETUP.CFG ] ; then ; rm SETUP.CFG ; fi

mv setup.txt SETUP.CFG

echo "have created SETUP.CFG for this run"

if [ ${pauses} == 'TRUE' ] ; then ; echo "Press ENTER to continue...\c" ; read junk ; echo "continuing..." ; fi

#   ----------------------------------------
#   create ASCDATA.CFG file
#  -----------------------------------------

if [ -a ASCDATA.TXT ]
then
rm ASCDATA.TXT
fi

echo "-90.0  -180.0  lat/lon of lower left corner (last record in file)"  > ASCDATA.TXT
echo "1.0     1.0    lat/lon spacing in degrees between data points"     >> ASCDATA.TXT
echo "180     360    lat/lon number of data points"                      >> ASCDATA.TXT
echo "2              default land use category"                          >> ASCDATA.TXT
echo "0.2            default roughness length (meters)"                  >> ASCDATA.TXT
echo "'../bdyfiles/' directory location of data files"                   >> ASCDATA.TXT
# echo "'"${bdyfiles_dir}"' directory location of data files"              >> ASCDATA.TXT

if [ -a ASCDATA.CFG ]
then
rm ASCDATA.CFG
fi

mv ASCDATA.TXT ASCDATA.CFG

# **********************************************************************
#    NOW THAT ALL INPUTS HAVE BEEN SET, RUN VMIXING
# **********************************************************************

# [markc@mercury2 ~/hysplit4/working_vmixing_tutorial]$ ../exec/vmixing
# Creates a time series of meteorological stability parameters
#  USAGE: vmixing (optional arguments)
# -p[process ID]
# -s[KBLS - stability method (1=default)]
# -t[KBLT - PBL mixing scheme (2=default)]
# -a[CAMEO optional variables (0[default]=No, 1=Yes, 2=Yes + Wind Direction]
# -m[TKEMIN - minimum TKE limit for KBLT=3 (0.001=default)]
# -w[an extra file for turbulent velocity variance (0[default]=No,1=Yes)]

# if existing output file is present from previous run, delete it
# or else you might think that you got a result from this run when you didn't
filename='STABILITY..txt'
if [ -a ${filename} ] ; then ; rm ${filename} ; fi

echo 'about to run vmixing'

EXEC_DIR='../exec/'

${EXEC_DIR}vmixing -s${KBLS} -t${KBLT} -a${extra_var}

# **********************************************************************
#      rename OUTPUT files to include RUN NAME
# **********************************************************************

file='CONTROL'        ; if [ -a ${file} ] ; then ; cp ${file} ${run_name}.ctl ; fi
file='MESSAGE..txt'   ; if [ -a ${file} ] ; then ; cp ${file} ${run_name}.msg ; fi
file='WARNING'        ; if [ -a ${file} ] ; then ; cp ${file} ${run_name}.warn ; fi
file='STABILITY..txt' ; if [ -a ${file} ] ; then ; cp ${file} ${run_name}.stability.txt ; fi
file='SETUP.CFG'      ; if [ -a ${file} ] ; then ; cp ${file} ${run_name}.cfg ; fi

# **********************************************************************
#     MOVE FILES to RESULTS SUBDIRECTORIES
# **********************************************************************

if [ -a ${run_name}.ctl  ]           ; then ; mv ${run_name}.ctl ${RESULTS_DIR} ; fi
if [ -a ${run_name}.msg  ]           ; then ; mv ${run_name}.msg ${RESULTS_DIR} ; fi
if [ -a ${run_name}.warn  ]          ; then ; mv ${run_name}.warn ${RESULTS_DIR} ; fi
if [ -a ${run_name}.stability.txt  ] ; then ; mv ${run_name}.stability.txt ${RESULTS_DIR} ; fi
if [ -a ${run_name}.cfg  ]           ; then ; mv ${run_name}.cfg ${RESULTS_DIR} ; fi

echo 'done with SET_VMIXING script; now leaving'
